@@ -1,13 +1,11 @@
-from os import path
-import sys
-import os
 import argparse
 import glob
-import colorama
+import os
+import sys
+from os import path
+from typing import Dict, List, Optional, cast
 
-from version_manager.settings_reader import read_settings_file
-from version_manager.options_set import get_parameter_values, get_parameters_from_file
-from version_manager.matchers.pattern import Pattern
+import colorama
 from termcolor_util import red, green, yellow, cyan, eprint
 
 from version_manager.command_current_version import print_current_tag_version
@@ -15,13 +13,15 @@ from version_manager.command_version_list import (
     print_single_tracked_version,
     print_all_tracked_versions,
 )
-
-from typing import Dict, List, Optional, cast
+from version_manager.matchers.pattern import Pattern
+from version_manager.options_set import get_parameter_values, get_parameters_from_file
+from version_manager.settings_reader import read_settings_file
 
 
 class ProgramArguments(object):
-    display: Optional[List[str]]
+    display: List[str]
     tag_name: bool
+    set_tag: str
     load: Optional[str]
     version: bool
     ignore_missing_parents: bool
@@ -77,15 +77,29 @@ def main() -> None:
         "values. Upstream values are still being patched if existing.",
     )
     parser.add_argument(
-        "--version", action="store_true", help="Show the program version (2021.03.4)",
+        "--version",
+        action="store_true",
+        help="Show the program version (2021.4.2)",
+    )
+    parser.add_argument(
+        "-st",
+        "--set-tag",
+        metavar="TAG",
+        help="Override the current tag returned by nested calls of `vm -t`. "
+             "This works by setting the VERSION_MANAGER_TAG in the environment "
+             "of the current process.",
     )
 
     argv: ProgramArguments = cast(ProgramArguments, parser.parse_args(sys.argv[1:]))
 
     if argv.version:
-        print(cyan("version-manager: 2021.03.4"))
+        print(cyan("version-manager: 2021.4.2"))
         sys.exit(0)
 
+    # update the current version name if needed
+    if argv.set_tag:
+        os.environ["VERSION_MANAGER_TAG"] = argv.set_tag
+
     if argv.tag_name:
         print_current_tag_version()
         sys.exit(0)
@@ -98,6 +112,7 @@ def main() -> None:
         override_parameters,
         argv.ignore_missing_parents,
         cwd=os.path.dirname(default_settings_file),
+        display_item=argv.display[0] if argv.display else None
     )
 
     # Display a single tracked version
